@@ -17,7 +17,7 @@ Contributors:
 #ifndef PERSIST_H
 #define PERSIST_H
 
-#define MOSQ_DB_VERSION 5
+#define MOSQ_DB_VERSION 6
 
 /* DB read/write */
 extern const unsigned char magic[15];
@@ -57,15 +57,28 @@ struct PF_cfg{
 	uint8_t dbid_size;
 };
 
-struct PF_client{
+struct PF_client_v5{
 	int64_t session_expiry_time;
 	uint32_t session_expiry_interval;
 	uint16_t last_mid;
 	uint16_t id_len;
 };
+struct PF_client{
+	/* struct PF_client_v5; */
+	int64_t session_expiry_time;
+	uint32_t session_expiry_interval;
+	uint16_t last_mid;
+	uint16_t id_len;
+
+	uint16_t listener_port;
+	uint16_t username_len;
+	/* tail: 4 byte padding, because 64bit member 
+	 * forces multiple of 8 for struct size */
+};
 struct P_client{
 	struct PF_client F;
 	char *client_id;
+	char *username;
 };
 
 
@@ -141,19 +154,19 @@ int persist__chunk_msg_store_read_v234(FILE *db_fptr, struct P_msg_store *chunk,
 int persist__chunk_retain_read_v234(FILE *db_fptr, struct P_retain *chunk);
 int persist__chunk_sub_read_v234(FILE *db_fptr, struct P_sub *chunk);
 
-int persist__chunk_header_read_v5(FILE *db_fptr, int *chunk, int *length);
-int persist__chunk_cfg_read_v5(FILE *db_fptr, struct PF_cfg *chunk);
-int persist__chunk_client_read_v5(FILE *db_fptr, struct P_client *chunk);
-int persist__chunk_client_msg_read_v5(FILE *db_fptr, struct P_client_msg *chunk, uint32_t length);
-int persist__chunk_msg_store_read_v5(FILE *db_fptr, struct P_msg_store *chunk, uint32_t length);
-int persist__chunk_retain_read_v5(FILE *db_fptr, struct P_retain *chunk);
-int persist__chunk_sub_read_v5(FILE *db_fptr, struct P_sub *chunk);
+int persist__chunk_header_read_v56(FILE *db_fptr, int *chunk, int *length);
+int persist__chunk_cfg_read_v56(FILE *db_fptr, struct PF_cfg *chunk);
+int persist__chunk_client_read_v56(FILE *db_fptr, struct P_client *chunk, int db_version);
+int persist__chunk_client_msg_read_v56(FILE *db_fptr, struct P_client_msg *chunk, uint32_t length);
+int persist__chunk_msg_store_read_v56(FILE *db_fptr, struct P_msg_store *chunk, uint32_t length);
+int persist__chunk_retain_read_v56(FILE *db_fptr, struct P_retain *chunk);
+int persist__chunk_sub_read_v56(FILE *db_fptr, struct P_sub *chunk);
 
-int persist__chunk_cfg_write_v5(FILE *db_fptr, struct PF_cfg *chunk);
-int persist__chunk_client_write_v5(FILE *db_fptr, struct P_client *chunk);
-int persist__chunk_client_msg_write_v5(FILE *db_fptr, struct P_client_msg *chunk);
-int persist__chunk_message_store_write_v5(FILE *db_fptr, struct P_msg_store *chunk);
-int persist__chunk_retain_write_v5(FILE *db_fptr, struct P_retain *chunk);
-int persist__chunk_sub_write_v5(FILE *db_fptr, struct P_sub *chunk);
+int persist__chunk_cfg_write_v6(FILE *db_fptr, struct PF_cfg *chunk);
+int persist__chunk_client_write_v6(FILE *db_fptr, struct P_client *chunk);
+int persist__chunk_client_msg_write_v6(FILE *db_fptr, struct P_client_msg *chunk);
+int persist__chunk_message_store_write_v6(FILE *db_fptr, struct P_msg_store *chunk);
+int persist__chunk_retain_write_v6(FILE *db_fptr, struct P_retain *chunk);
+int persist__chunk_sub_write_v6(FILE *db_fptr, struct P_sub *chunk);
 
 #endif
